###################################################
### chunk number 1: 
###################################################
library(CNVassoc)


###################################################
### chunk number 2: 
###################################################
library(xtable)


###################################################
### chunk number 3: 
###################################################
data(dataMLPA)
head(dataMLPA)


###################################################
### chunk number 4: 
###################################################
par(mfrow=c(2,2),mar=c(3,4,3,1))
hist(dataMLPA$Gene1,main="Gene 1 signal histogram",xlab="",ylab="frequency")
hist(dataMLPA$Gene2,main="Gene 2 signal histogram",xlab="",ylab="frequency")
par(xaxs="i")
plot(density(dataMLPA$Gene1),main="Gene 1 signal density function",xlab="",ylab="density")
plot(density(dataMLPA$Gene2),main="Gene 2 signal density function",xlab="",ylab="density")


###################################################
### chunk number 5: 
###################################################
plotSignal(dataMLPA$Gene2,case.control=dataMLPA$casco)


###################################################
### chunk number 6: 
###################################################
plotSignal(dataMLPA$Gene2,case.control=dataMLPA$casco)


###################################################
### chunk number 7: 
###################################################
plotSignal(dataMLPA$Gene2,case.control=dataMLPA$quanti)


###################################################
### chunk number 8: 
###################################################
plotSignal(dataMLPA$Gene2,case.control=dataMLPA$quanti)


###################################################
### chunk number 9: 
###################################################
cutpoints <- c(0.08470221, 0.40485249)


###################################################
### chunk number 10: 
###################################################
cutpoints


###################################################
### chunk number 11: 
###################################################
CNV.1<-cnv(x=dataMLPA$Gene1, threshold.0=0.06, num.class=3, mix.method = "mixdist")


###################################################
### chunk number 12: 
###################################################
CNV.2<-cnv(x=dataMLPA$Gene2, threshold.0=0.01, mix.method = "mixdist")


###################################################
### chunk number 13: 
###################################################
probs.2<-getProbs(CNV.2)


###################################################
### chunk number 14: 
###################################################
CNV.2probs<-cnv(probs.2)


###################################################
### chunk number 15: 
###################################################
CNV.2th<-cnv(x=dataMLPA$Gene2, cutoffs=cutpoints)


###################################################
### chunk number 16: 
###################################################
CNV.1


###################################################
### chunk number 17: 
###################################################
CNV.2


###################################################
### chunk number 18: 
###################################################
CNV.2probs


###################################################
### chunk number 19: 
###################################################
pdf("./figures/fig2a.pdf")
plot(CNV.1, case.control=dataMLPA$casco, main="Gene 1")
dev.off()
pdf("./figures/fig2b.pdf")
plot(CNV.2, case.control=dataMLPA$casco, main="Gene 2")
dev.off()


###################################################
### chunk number 20: 
###################################################
plot(CNV.2probs, case.control=dataMLPA$casco)


###################################################
### chunk number 21: 
###################################################
CNVassoc::getQualityScore(CNV.1,type="class")
CNVassoc::getQualityScore(CNV.2,type="class")


###################################################
### chunk number 22: 
###################################################
CNVassoc::getQualityScore(CNV.1,type="CNVtools")
CNVassoc::getQualityScore(CNV.2,type="CNVtools")


###################################################
### chunk number 23: 
###################################################
CNVassoc::getQualityScore(CNV.1,type="CANARY")
CNVassoc::getQualityScore(CNV.2,type="CANARY")


###################################################
### chunk number 24: 
###################################################
model1mul<-CNVassoc(casco~CNV.1,data=dataMLPA,model="mul")
model2mul<-CNVassoc(casco~CNV.2,data=dataMLPA,model="mul")


###################################################
### chunk number 25: 
###################################################
model1mul


###################################################
### chunk number 26: 
###################################################
model2mul


###################################################
### chunk number 27: 
###################################################
summary(model1mul)


###################################################
### chunk number 28: 
###################################################
summary(model2mul)


###################################################
### chunk number 29: 
###################################################
mod<-CNVassoc(quanti ~ CNV.2 + cov, family = "gaussian", data = dataMLPA, model = 'add', emsteps=10)
mod


###################################################
### chunk number 30: 
###################################################
summary(mod)


###################################################
### chunk number 31: 
###################################################
CNVtest(model1mul,type="Wald")
CNVtest(model1mul,type="LRT")


###################################################
### chunk number 32: 
###################################################
CNVtest(model2mul,type="Wald")
CNVtest(model2mul,type="LRT")


###################################################
### chunk number 33: 
###################################################
coef(summary(model1mul,ref=2))


###################################################
### chunk number 34: 
###################################################
model2add<-CNVassoc(casco~CNV.2, data=dataMLPA, model="add")
model2add


###################################################
### chunk number 35: 
###################################################
summary(model2add)


###################################################
### chunk number 36: 
###################################################
anova(model2mul,model2add)


###################################################
### chunk number 37: 
###################################################
data(NeveData)
intensities<-NeveData$data
pheno<-NeveData$pheno


###################################################
### chunk number 38: 
###################################################
data(NeveCalled)


###################################################
### chunk number 39: 
###################################################
probs<-getProbs(NeveCalled)


###################################################
### chunk number 40: 
###################################################
probs[1:5,1:7]


###################################################
### chunk number 41: 
###################################################
data(NeveRegions)


###################################################
### chunk number 42: 
###################################################
probsRegions<-getProbsRegions(probs, NeveRegions, intensities)


###################################################
### chunk number 43: 
###################################################
pvals<-multiCNVassoc(probsRegions, formula="pheno~CNV",
model="mult", num.copies=0:2, cnv.tol=0.01)


###################################################
### chunk number 44: 
###################################################
pvalsBH<-getPvalBH(pvals)
head(pvalsBH)


###################################################
### chunk number 45: 
###################################################
cumsum(table(cut(pvalsBH[,2],c(-Inf,1e-5,1e-4,1e-3,1e-2,0.05))))


###################################################
### chunk number 46: 
###################################################
data(A112)


###################################################
### chunk number 47: 
###################################################
head(A112)


###################################################
### chunk number 48: 
###################################################
head(A112)


###################################################
### chunk number 49: 
###################################################
library(CNVtools)


###################################################
### chunk number 50: 
###################################################
raw.signal <- as.matrix(A112[, -c(1, 2)])
dimnames(raw.signal)[[1]] <- A112$subject


###################################################
### chunk number 51: 
###################################################
pca.signal <- apply.pca(raw.signal)


###################################################
### chunk number 52: 
###################################################
ncomp <- 3
batches <- factor(A112$cohort)
sample <- factor(A112$subject)
fit.pca <- CNVtest.binary(signal = pca.signal, sample = sample, batch = batches, ncomp = ncomp, n.H0 = 3, n.H1 = 0, model.var = "~ strata(cn)")


###################################################
### chunk number 53: 
###################################################
pca.posterior <- as.matrix((fit.pca$posterior.H0)[, paste("P", seq(1:ncomp), sep = "")])
dimnames(pca.posterior)[[1]] <- (fit.pca$posterior.H0)$subject
ldf.signal <- apply.ldf(raw.signal, pca.posterior)


###################################################
### chunk number 54: 
###################################################
CNV<-cnv(ldf.signal, batches=batches, num.class=3, mix="mclust")
CNV


###################################################
### chunk number 55: 
###################################################
plot(CNV)


###################################################
### chunk number 56: 
###################################################
trait <- ifelse(A112$cohort == "58C", 0, 1)
fit <- CNVassoc(trait ~ CNV, model = "add")
CNVtest(fit,"LRT")


###################################################
### chunk number 57: 
###################################################
# by default CNVtest.binary assumes: model.var = "~ strata(batch, cn)", model.disease = "~ cn" (trend CNV effect, and different vars per batch).
fit.cnvtools <- CNVtest.binary(signal=ldf.signal,sample=sample,batch=batches,disease.status=trait,ncomp=ncomp,n.H0=3,n.H1=1,model.var="~cn")
chi.cnvtools  <-  -2*(fit.cnvtools$model.H0$lnL-fit.cnvtools$model.H1$lnL)


###################################################
### chunk number 58: 
###################################################
fit <- CNVassoc(trait ~ CNV)
CNVtest(fit,"LRT")


###################################################
### chunk number 59: 
###################################################
fit.cnvtools <- CNVtest.binary(signal=ldf.signal,sample=sample,batch=batches,disease.status=trait,ncomp=3,n.H0=3,n.H1=1,model.disease="~as.factor(cn)")
chi.cnvtools  <-  -2*(fit.cnvtools$model.H0$lnL-fit.cnvtools$model.H1$lnL)


###################################################
### chunk number 60: 
###################################################
data(SNPTEST)
dim(cases)
dim(controls)


###################################################
### chunk number 61: 
###################################################
cases[1:10,1:11]


###################################################
### chunk number 62: 
###################################################
cases[1:10,1:11]


###################################################
### chunk number 63: 
###################################################
controls[1:10,1:11]


###################################################
### chunk number 64: 
###################################################
controls[1:10,1:11]


###################################################
### chunk number 65: 
###################################################
nSNP<-nrow(cases)
probs<-lapply(1:nSNP, function(i) {
  snpi.cases<-matrix(as.double(cases[i,6:ncol(cases)]),ncol=3,byrow=TRUE)
  snpi.controls<-matrix(as.double(controls[i,6:ncol(controls)]),ncol=3,byrow=TRUE)
  return(rbind(snpi.cases,snpi.controls))
})


###################################################
### chunk number 66: 
###################################################
casecon<-rep(1:0,c(500,500))


###################################################
### chunk number 67: 
###################################################
pvals<-multiCNVassoc(probs, formula="casecon~CNV",model="add", num.copies=0:2, cnv.tol=0.001)


###################################################
### chunk number 68: 
###################################################
pvalsBH<-getPvalBH(pvals)
head(pvalsBH)


###################################################
### chunk number 69: 
###################################################
table(cut(pvalsBH[,2],c(-Inf,1e-3,1e-2,0.05,0.1,Inf)))


###################################################
### chunk number 70: 
###################################################
set.seed(123456)
rr<-1.7
incid0<-0.12
lambda<-c(incid0,incid0*rr,incid0*rr^2)
dsim<-simCNVdataPois(n=4000,mu.surrog=0:2,sd.surrog=rep(0.4,3),w=c(0.25,0.5,0.25),lambda=lambda)
head(dsim)


###################################################
### chunk number 71: 
###################################################
CNV<-cnv(dsim$surrog,mix="mclust")
CNV


###################################################
### chunk number 72: 
###################################################
fit<-CNVassoc(resp~CNV, data=dsim, family="poisson", model="add")
coef(summary(fit))


###################################################
### chunk number 73: 
###################################################
fit.gold<-glm(resp~cnv, data=dsim, family="poisson")
table.gold<-c(exp(c(coef(fit.gold)[2],confint(fit.gold)[2,])),coef(summary(fit.gold))[2,4])
names(table.gold)<-c("RR","lower","upper","p-value")
table.gold


###################################################
### chunk number 74: 
###################################################
fit.naive<-glm(resp~CNV, data=dsim, family="poisson")
table.naive<-c(exp(c(coef(fit.naive)[2],confint(fit.naive)[2,])),coef(summary(fit.naive))[2,4])
names(table.naive)<-c("RR","lower","upper","p-value")
table.naive


###################################################
### chunk number 75: 
###################################################
taula<-rbind(
table.gold[1:3],
coef(summary(fit))[,c("RR","lower.lim","upper.lim")],
table.naive[1:3])
rownames(taula)<-c("Gold","LC","Naive")
xtable(taula,"Comparison of RR estimated by the gold standard model, a latent class model (LC) and naive approach",label="table-compare")


###################################################
### chunk number 76: 
###################################################
set.seed(123456)
n<-5000
w<-c(0.25,0.5,0.25)
mu.surrog<-0:2
sd.surrog<-rep(0.4,3)
hr<-1.5
incid0<-0.05
lambda<-c(incid0,incid0*hr,incid0*hr^2)
shape<-1
scale <-lambda^(-1/shape)
perc.obs<-0.10
time.cens<-qweibull(perc.obs,mean(shape),mean(scale))
dsim<-simCNVdataWeibull(n, mu.surrog, sd.surrog, w, lambda, shape, time.cens)
head(dsim)


###################################################
### chunk number 77: 
###################################################
CNV<-cnv(dsim$surrog,mix="mclust")
CNV


###################################################
### chunk number 78: 
###################################################
fit<-CNVassoc(Surv(resp,cens)~CNV, data=dsim, family="weibull", model="add")
coef(summary(fit))


